@@ -19,7 +19,6 @@ inittrayicon(void)
 	
     pytrayicon_register_classes (d);
 
-    if (PyErr_Occurred ()) {
-	Py_FatalError ("can't initialise module trayicon :(");
-    }
+    PyErr_Warn(PyExc_DeprecationWarning, "the module egg.trayicon is deprecated;"
+               " equivalent functionality can now be found in pygtk 2.10");
 }
